@@ -3,7 +3,7 @@ package Acme::CPANModules::NO_COLOR;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-06-01'; # DATE
 our $DIST = 'Acme-CPANModules-NO_COLOR'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $LIST = {
     summary => "Modules that follow the NO_COLOR convention",
@@ -18,18 +18,28 @@ If you know of other modules that should be listed here, please contact me.
 
 _
     entries => [
-        {module=>'App::DiffTarballs'},
-        {module=>'App::hr'},
+        {module=>'App::ccdiff', script=>'ccdiff'},
+        {module=>'App::Codeowners', script=>'git-codeowners'},
+        {module=>'App::DiffTarballs', script=>'diff-tarballs'},
+        {module=>'App::hr', script=>'hr'},
+        {module=>'App::riap', script=>'riap'},
+        {module=>'App::rsynccolor', script=>'rsynccolor'},
         {module=>'Color::ANSI::Util'},
         {module=>'Data::Dump::Color'},
         {module=>'Debug::Print'},
         {module=>'Log::Any::Adapter::Screen'},
         {module=>'Log::ger::Output::Screen'},
+        {module=>'Parse::Netstat::Colorizer', script=>'cnetstat'},
+        {module=>'Proc::ProcessTable::ncps', script=>'ncps'},
         {module=>'Progress::Any::Output::TermProgressBar'},
+        {module=>'Search::ESsearcher', script=>'essearcher'},
+        {module=>'Term::ANSIColor'},
         {module=>'Term::ANSIColor::Conditional'},
         {module=>'Term::ANSIColor::Patch::Conditional'},
         {module=>'Term::App::Roles'},
-        {module=>'Text::ANSITable'},
+        {module=>'Term::App::Roles::Attrs'},
+        {module=>'Text::CSV_XS', script=>'csvdiff'},
+        {module=>'Tree::Shell', script=>'treesh'},
     ],
     links => [
         {url=>'pm:Acme::CPANModules::COLOR'},
@@ -52,7 +62,7 @@ Acme::CPANModules::NO_COLOR - Modules that follow the NO_COLOR convention
 
 =head1 VERSION
 
-This document describes version 0.006 of Acme::CPANModules::NO_COLOR (from Perl distribution Acme-CPANModules-NO_COLOR), released on 2021-06-01.
+This document describes version 0.007 of Acme::CPANModules::NO_COLOR (from Perl distribution Acme-CPANModules-NO_COLOR), released on 2021-06-01.
 
 =head1 DESCRIPTION
 
@@ -67,10 +77,18 @@ If you know of other modules that should be listed here, please contact me.
 
 =over
 
+=item * L<App::ccdiff>
+
+=item * L<App::Codeowners>
+
 =item * L<App::DiffTarballs>
 
 =item * L<App::hr>
 
+=item * L<App::riap>
+
+=item * L<App::rsynccolor>
+
 =item * L<Color::ANSI::Util>
 
 =item * L<Data::Dump::Color>
@@ -81,15 +99,27 @@ If you know of other modules that should be listed here, please contact me.
 
 =item * L<Log::ger::Output::Screen>
 
+=item * L<Parse::Netstat::Colorizer>
+
+=item * L<Proc::ProcessTable::ncps>
+
 =item * L<Progress::Any::Output::TermProgressBar>
 
+=item * L<Search::ESsearcher>
+
+=item * L<Term::ANSIColor>
+
 =item * L<Term::ANSIColor::Conditional>
 
 =item * L<Term::ANSIColor::Patch::Conditional>
 
 =item * L<Term::App::Roles>
 
-=item * L<Text::ANSITable>
+=item * L<Term::App::Roles::Attrs>
+
+=item * L<Text::CSV_XS>
+
+=item * L<Tree::Shell>
 
 =back
 
